@@ -1,9 +1,13 @@
+"""
+Tomoscope specific codes
+
+:Author(s): **Anton Lu**
+"""
 import logging
 from os import path
 
 import numpy as np
 
-from ..data import data_treatment as dtreat
 from ..utils import tomo_output as tomoout
 
 
@@ -43,4 +47,4 @@ def save_profile(prof: np.ndarray, film: int, output_path: str):
 
     with open(path.join(output_path, f'profile{film + 1:03d}.data'), 'w') as f:
         for element in prof:
-            f.write(f' {element:0.7E}\n')
\ No newline at end of file
+            f.write(f' {element:0.7E}\n')
